Documentation TODO
==================

Global TODO
-----------

    - Clean up docstrings
    - Shorten Index
    - Split up Index?
    - Shorten Index title lengths
    - Import nautical glossary
    - Multilang

Local TODO
----------

.. todolist::

